
;;;;;;;;;;;;;;;;;;;;;;;;;;;
;  Varariable definition  ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals [
         index-stop-year  ; expected proportion of agents who would stop farming per year
         index-growth     ; difference in the expected agents' buying capacity per scenario
        ]              


breed [agents agent]      ; an agent represent a farm 


agents-own [
            ; AGENTS' WILLINGNESS AND ABILITY
               agent-type                 ; decision-making strategy 
              
            ; AGENTS' ABILITY 
               agent-id                   ; agent id 
               agent-age                  ; age of the farm head
               agent-production           ; dsu. per ha
               agent-business-type        ; agribusiness type (e.g. livestock, intensive livestock, etc)
               agent-previous-transaction ; average transactions made between 2001-2005. 
               agent-production-scale     ; total amount of dsu. (Dutch Standard Units; in 2005 1 dsu =  1400)
               agent-production-class     ; class of farm based on production scale 
               agent-production-extra     ; extra dsu per hectare due to differences between spatial data and census data (> 2 dsu/ha)
               agent-farm-size            ; farm size
               agent-farm-size-initial    ; initial farm size   
               agent-farm-size-previous   ; simulated famr size 
               agent-farm-list            ; list of owned patches
               agent-field-list           ; list of owned fields
               agent-trees                ; does the agent have landscape elements in his farm      
               agent-national-landscape   ; whether an agent is located in the national landscape.
               agent-surrounding-nature   ; surrounding nature areas to the agent
                                          
            ; INTERNAL SYSTEM MEMORY: farm expansion
               agent-transactions         ; list of land transactions of the last 5 years
               agent-farm-expansion       ; land-changes: amount of land that the agent has bought or sell in the last year
               agent-farm-expansion-sum   ; land-changes: amount of land that the agent has bought or sell in the last 5 years
               agent-decision-trees       ; number of years since the last decision on landscape elements
               agent-new                  ; whether the agent is an immigrant from the cities (only in the A1 scenario)
               agent-cut                  ; whether the agent cut landscape elements 
               agent-plant                ; whether the agent planted landscape elements
               agent-field-sell           ; which field would be sold
            
            ; AGENTS' OPTIONS     
              ; Thresholds between agents' options based on the agent type       
                 p-stop-type              ; stop farming 
                 p-expand-type            ; buy land 
                 p-shrink-type            ; sell land 
                 p-protect-type           ; protect nature 
              ; farm feedbacks
                 p-expand-feedback        ; influence of the previous land transactions on future options.       
                 p-stop-feedback          ; influence ot previous land transactions on stop farming
              ; exogenous processes
                 p-exogenous-stop         ; influence of the exogenous processes on farm cessation
                 p-business-stop          ; correction of the influence of the exogenous processes on stop farming per agribusiness type
                 p-exogenous-expand       ; influence of the exogenous processes on farm expansion
                 p-scenario-ehs           ; influence of the exogenous processes on the development of the EHS
              ; final probability
                 p-stop                   ; probability to stop farming 
                 p-expand                 ; probability to expand farm
                 p-shrink                 ; probability to sell part of the land
                 p-protect                ; probability to protect/cut landscape elements 
              ; buyer selection 
                 weight-buy               ; the sum of the other weighting values 
                 weight-size              ; whether the farm is bigger than the farm to buy
                 weight-distance          ; whether the agent is close to the seller
                 weight-type              ; whether the agent is an expansionist

            ; AGENTS' DECISIONS & ACTIONS 
               agent-cessation            ; stop farming or inherit farm.
               agent-expansion            ; buy, keep or sell.
               agent-protection           ; plant, keep or cut the landscape elements.
               agent-random-stop          ; random number: decisions on farm cessation 
               agent-random-expand        ; random number: decisions on farm expansion
               agent-random-protect       ; random number: decisions on landscape protection
           ]


patches-own [
             ; DEFINITION OF THE PATCHES (PIXELS)
             patch-size-model       ; size of each patch in relation to the real field size
             patch-farm-size        ; area of the farm to which the patch belongs
             parcel-field-number    ; field to which the pixel belongs
             ; DEFINITION OF THE FIELDS 
             field-owner-id         ; field owner 
             field-size             ; size of the field 
             field-distance-owner   ; distance to the agent's house
             field-suitability      ; suitability of the field for agriculture 
             field-landuse          ; land-use type of the field
             field-le               ; landscape elements in the field
             field-le-current       ; length of landscape elements in a pixel
             field-le-potential     ; perimeter of the field 
             field-ehs              ; whether the field belongs to the area selected for the EHS
            ]





;;;;;;;;;;;;;;;;;;;;;;;;;;
;  MODEL INITIALISATION  ;
;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  ca                          ; clear all 
  ; FIELDS 
  definition-fields           ; define the landuse type and which pixels belongs to which field and how owns them. 

  ; AGENTS 
  definition-agents           ; create, allocate and characterise each agent for the first time
  
  ; AGENTS' INITIAL CONDITIONS 
  option-agent-type           ; agent type probabilities
  option-agent-initial        ; initial agent's probability 

  ; SCENARIO IMPLEMENTATION: 
  feedback-exogenous-scenario ; define the influence of the exogenous processes of the scenarios  
  
  ; AGENTS' INITIAL OPTIOINS & DECISIONS
  farm-cessation-option       ; initial likelihood to stop farming 
  farm-cessation-decision     ; initial decision on farm cessation
    
  ; REPRESENTATION OF THE LANDSCAPE
  update-map                  ; landscape changes
  update-plot                 ; plot changes
end
  




;;;;;;;;;;;;;;;
;  MODEL RUN  ;
;;;;;;;;;;;;;;;

to go 
  tick                         ; a time step          
  ; FEEDBACKS 
  feedback-internal-decisions  ; represent the agent decision-making trajectory 
  feedback-internal-actions    ; define the influence of previous actions        
  
  ; OPTIONS
  farm-cessation-option        ; likelihood to stop farming
  farm-expansion-option        ; likelihood to buy/sell land                
  protection-trees-option      ; likelihood to cut/plant landscape elements 
  
  ; DECISIONS
  farm-cessation-decision      ; who is going to stop farming
  farm-expansion-decision      ; who is going to buy/sell land
  protection-trees-decision    ; who is going to protect/cut/plant landscape elements
  
  ; ACTIONS 
  farm-cessation-action        ; agents >= 50 years can stop farming or new agents can inherit the farm.
  farm-expansion-action        ; whether agents buy or sell fields
  protection-trees-action      ; whether agents practice landscape conservation
  
  ; UPDATES
  update-agent-transactions    ; update agent's farm size and transactions       
  update-agent                 ; update agents' willingness and ability
  update-map                   ; update the landscape 
  update-plot                  ; update all the plots
  
  ; STOP THE MODEL
  ; The period modelled is 2005 - 2020      
  if (ticks = 15) 
      [
       export-data            ; Save some data for further analyses 
       stop                   ; The model stops
      ]      
end
  





;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; INITIAL CONDITIONS & SUB-PROCESSSES ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; INPUT DATA
to definition-fields
  
  ; Reading external file to define the land-use type for each field
  file-open "land_types.txt"
  foreach sort patches [ask ? [set field-landuse file-read] ]
  file-close

  ; Reading external file to define which patches belong to the same field. 
  file-open "fields_id.txt"
  foreach sort patches [ask ? [set parcel-field-number file-read] ]
  file-close

  ; Reading external file to define the size of each patch related to field size. 
  file-open "fields_size.txt"
  foreach sort patches [ask ? [set field-size file-read] ]
  file-close 
  
  ; Reading external file to define the size of each patch related to field size. 
  file-open "fields_area.txt"
  foreach sort patches [ask ? [set patch-size-model file-read] ]
  file-close

  ; Reading external file to define which patches belong to the same agent. 
  file-open "fields_owner.txt"
  foreach sort patches [ask ? [set field-owner-id file-read] ]
  file-close
  
  ; Reading external file to define the maximum potential of landscape elements in a field. 
  file-open "field_suitability.txt"
  foreach sort patches [ask ? [set field-suitability file-read] ]
  file-close    

  ; Reading external file to define whether a field has a landscape elements. 
  file-open "fields_le.txt"
  foreach sort patches [ask ? [set field-le file-read] ]
  file-close
  
  ; Reading external file to define the maximum potential of landscape elements in a field. 
  file-open "fields_le_potential.txt"
  foreach sort patches [ask ? [set field-le-potential file-read]]
  file-close  

  ; Reading external file to define the reduction in the density of landscape elements . 
  file-open "fields_le_current.txt"
  foreach sort patches [ask ? [set field-le-current file-read] ]
  file-close
  
  ; Reading external file to define the neighbour field.
  file-open "fields_ehs.txt"
  foreach sort patches [ask ? [set field-ehs file-read]]
  file-close  
end


to definition-agents 
   
  create-agents 2741 ; Number of agents in the study area based on the the file try_agent_id.txt
  ask agents [hide-turtle]
  
  random-seed new-seed  ; Defines a different set of random numbers each time the model is run
  
  ; Id: reading external file to define the Id of each agent.
  file-open "agent_id.txt" 
  foreach sort agents [ask ? [set agent-id file-read]]
  file-close

  ; Location: reading external file to define the coordinates of each agent
  file-open "agent_x.txt" 
  foreach sort agents [ask ? [set xcor file-read] ]
  file-close
  
  file-open "agent_y.txt" 
  foreach sort agents [ask ? [set ycor file-read] ]
  file-close
  
  ; Agent type: reading external file to define agent type.  
  file-open "agent_type.txt" 
  foreach sort agents [ask ? [set agent-type file-read] ]
  file-close  
  
  ; Age: reading external file to define agent's age.
  file-open "agent_age.txt" 
  foreach sort agents [ask ? [set agent-age file-read] ]
  file-close

  ; Business: reading external file to define agent's business type.
  file-open "agent_business.txt" 
  foreach sort agents [ask ? [set agent-business-type file-read] ]
  file-close
  
  ; Past land transactions: reading external file to define agents' land transactions between 2001-2005.
  file-open "agent_trans.txt" 
  foreach sort agents [ask ? [set agent-previous-transaction file-read] ]
  file-close
  
  ; Production scale: reading external file to define agents' size of production per ha. in 2005 based on the area in the map.
  ; To reduce agents with a very high agent-production, a maximum was established based on agribusiness type, farm and production 
  ; (empirical data). The difference of dsu for those higher than 90 percentile was added as agent-production-extra. 
  file-open "agent_product.txt" 
  foreach sort agents [ask ? [set agent-production file-read] ]
  file-close

  ; Production scale extra: reading external file to define the extra amount of dsu due to differences between the census data and the map.
  file-open "agent_product_extra.txt" 
  foreach sort agents [ask ? [set agent-production-extra file-read] ]
  file-close  
    
  ; Postcode area: reading external file to define agents' postcode area (4-characters).
  file-open "agent_nlandscape.txt" 
  foreach sort agents [ask ? [set agent-national-landscape file-read] ]
  file-close
  
  ; Calculation of other agents' characteristics
  ask agents 
      [
       set agent-transactions n-values 5 [agent-previous-transaction]            ; list the transactions (2001-2005) in five years 
       set agent-farm-expansion-sum (sum agent-transactions)                     ; amount of land that an agent has bought/sold in the last 5 years
       set agent-farm-expansion 0                                                ; create the value of land-transaction                   
       set agent-farm-list patches with [field-owner-id = [agent-id] of myself]  ; create a list of patches that belong to each agent
       set agent-field-list remove-duplicates definition-farms                   ; redefine the list to the fields that belong to each agent
       set agent-farm-size (sum [patch-size-model] of agent-farm-list)           ; define the farm size
       set agent-farm-size-previous agent-farm-size                              ; define the previous farm size   
       set agent-farm-size-initial (sum [patch-size-model] of agent-farm-list)   ; define the initial farm size
       set agent-decision-trees random 10                                        ; define randomly the year an agent participated in a policy to protect these elements
       set agent-cessation ""                                                    ; definition of the variable
      ]
  update-agent 
end



to-report definition-farms []
  report [parcel-field-number] of agent-farm-list  ; This report lists all the fields that belong to each agent. 
end  
  
  


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; UPDATE OF THE SUB-PROCESSES  ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  

to update-agent
  
  ; Structure (no. patches) that belongs to each agent. 
  ask agents 
      [
       ; Define the production of each agent                           
       ifelse agent-farm-size < 1 
           [set agent-production-scale (agent-production + agent-production-extra)]  ; This avoids the numerical problems of agents with very small farms.
           [set agent-production-scale ((agent-farm-size * agent-production) + agent-production-extra)]
       
       ; Define the production scale of each agent         
       if agent-production-scale <= 20 [set agent-production-class "hobby"] 
       if agent-production-scale > 20  [set agent-production-class "small"]
       if agent-production-scale > 50  [set agent-production-class "medium"]
       if agent-production-scale > 100 [set agent-production-class "large"]        
       
       let patch-farm-area agent-farm-size            ; define the farm to which a patch belongs
       ask agent-farm-list 
           [
            set field-distance-owner distance myself  ; define the distance of each patch to the agent-house
            set patch-farm-size patch-farm-area       ; define the size of the farm to which a patch belongs
           ]

       ; Define whether an agent has fields that are with landscape elements or not
       ifelse any? agent-farm-list with [(field-le = 1)]
           [set agent-trees 1]                                        
           [set agent-trees 0]                        
           
       ; FEEDBACK BETWEEN AGENT TYPES - HOBBY VS. OTHERS
       ; Update the agent type of new hobby agents
       if (agent-type != 1) and (agent-production-scale <= 20)  
           [
            set agent-type 1
            option-agent-type
           ]
         
       ; Changes in agent types from hobby to conventional diversifier agent 
       if (agent-type = 1) and (agent-production-scale > 20) and (agent-new = 0) 
           [
            set agent-type 2
            option-agent-type
           ]
        set agent-age (agent-age + 1)                        ; agents get older
        set agent-decision-trees (agent-decision-trees + 1)  ; agents' participation in policies get another year             
      ]
end



  
to update-agent-transactions                                         
ask agents [  
            ; Update the list of action-agent-farm-expansion
            set agent-farm-size (sum [patch-size-model] of agent-farm-list)        ; update agents' farm size
            set agent-farm-expansion (agent-farm-size - agent-farm-size-previous)  ; whether an agent has previously expanded or decreased land
            set agent-farm-size-previous agent-farm-size                           ; define the current farm size as previous for the subsequent year
            set agent-transactions but-first agent-transactions                    ; delete the land transaction of the first year 
            set agent-transactions lput agent-farm-expansion agent-transactions    ; add the land transactions of the current year
            set agent-farm-expansion-sum (sum agent-transactions)                  ; update the amount of land that an agent has bought/sold in the last 5 years
            let patch-farm-area agent-farm-size                                    ; define a variable that can be used for defining the farm to which a patch belongs
            ask agent-farm-list [set patch-farm-size patch-farm-area]              ; update the farm size to which a field belongs
          ]  
end  



to update-map
  view-field-le  ; The landscape of the area is updated
end


to update-plot ; Different plots of the modelling process
  
  ; Graph of the relative number of agents per type
  set-current-plot "Percentage of agents"
  ;plot count agents 
  set-current-plot-pen "Hobby"
  plot (count agents with [agent-type = 1] / count agents * 100)
  set-current-plot-pen "Conventional"
  plot (count agents with [agent-type = 2] / count agents * 100)
  set-current-plot-pen "Diversifier"
  plot (count agents with [agent-type = 3] / count agents * 100)
  set-current-plot-pen "Conventional expansionist"
  plot (count agents with [agent-type = 4] / count agents * 100)
  set-current-plot-pen "Diversifier expansionist"
  plot (count agents with [agent-type = 5] / count agents * 100)
  
  ; Graph of the mean farm size (ha) per agent type
  set-current-plot "Mean farm size"
  set-current-plot-pen "Hobby"
  plot (sum [agent-farm-size] of agents with [agent-type = 1]) / (count agents with [agent-type = 1])
  set-current-plot-pen "Conventional"
  plot (sum [agent-farm-size] of agents with [agent-type = 2]) / (count agents with [agent-type = 2])
  set-current-plot-pen "Diversifier"
  plot (sum [agent-farm-size] of agents with [agent-type = 3]) / (count agents with [agent-type = 3])
  set-current-plot-pen "Conventional expansionist"
  plot (sum [agent-farm-size] of agents with [agent-type = 4]) / (count agents with [agent-type = 4])
  set-current-plot-pen "Diversifier expansionist"
  plot (sum [agent-farm-size] of agents with [agent-type = 5]) / (count agents with [agent-type = 5])
  
  ; Graph of the percentage of land managed per agent type 
  set-current-plot "Percentage of area" 
  set-current-plot-pen "Hobby"
  plot (sum [agent-farm-size] of agents with [agent-type = 1]) / (sum [agent-farm-size] of agents) * 100
  set-current-plot-pen "Conventional"
  plot (sum [agent-farm-size] of agents with [agent-type = 2]) / (sum [agent-farm-size] of agents) * 100
  set-current-plot-pen "Diversifier"
  plot (sum [agent-farm-size] of agents with [agent-type = 3]) / (sum [agent-farm-size] of agents) * 100
  set-current-plot-pen "Conventional expansionist"
  plot (sum [agent-farm-size] of agents with [agent-type = 4]) / (sum [agent-farm-size] of agents) * 100 
  set-current-plot-pen "Diversifier expansionist"
  plot (sum [agent-farm-size] of agents with [agent-type = 5]) / (sum [agent-farm-size] of agents) * 100 
  
  ; Graph of the amount of new nature 
  set-current-plot "Nature"
  set-current-plot-pen "per year"
  plot (sum [patch-size-model] of patches with [field-owner-id = 9999])
   
  ; Graph of the total number of agents with landscape elements in their fields
  set-current-plot "Trees"
  ;set-current-plot-pen "Agents"
  ;plot count agents 
  set-current-plot-pen "Hobby"
  plot (count agents with [agent-type = 1 and any? agent-farm-list with [field-le = 1]])
  set-current-plot-pen "Conventional"
  plot (count agents with [agent-type = 2 and any? agent-farm-list with [field-le = 1]])
  set-current-plot-pen "Diversifier"
  plot (count agents with [agent-type = 3 and any? agent-farm-list with [field-le = 1]])
  set-current-plot-pen "Conventional expansionist"
  plot (count agents with [agent-type = 4 and any? agent-farm-list with [field-le = 1]])
  set-current-plot-pen "Diversifier expansionist"
  plot (count agents with [agent-type = 5 and any? agent-farm-list with [field-le = 1]])

end






; DIFFERENT ALTERNATIVES TO VIEW THE STUDY AREA
to view-agent-type
  ask agents 
      [
       if agent-type = 1 [ask agent-farm-list [set pcolor red  - 2]]
       if agent-type = 2 [ask agent-farm-list [set pcolor red  + 1]]
       if agent-type = 3 [ask agent-farm-list [set pcolor red  + 1]]
       if agent-type = 4 [ask agent-farm-list [set pcolor red  + 4]]
       if agent-type = 5 [ask agent-farm-list [set pcolor red  + 4]]
      ]
             
  ask patches 
      [ 
       if field-landuse = 0      [set pcolor white]    ; No data 
       if field-landuse = 6      [set pcolor white]    ; Urban areas  
       if field-landuse = 5      [set pcolor white]    ; Water
       if field-landuse = 4      [set pcolor white]    ; Nature areas             
      ]
end



to view-field-le
  ask patches 
      [
       ; fields with linear landscape elements
  
       ifelse field-le = 1 
           [set pcolor 56]    ; fields with landscape elements.  
           [set pcolor 59]    ; fields without landscape elements. 
                                     
       if field-landuse = 0      [set pcolor white]    ; No data 
       if field-landuse = 6      [set pcolor white]    ; Urban areas  
       if field-landuse = 5      [set pcolor white]    ; Water
       if field-landuse = 4      [set pcolor 54]       ; Nature areas   
      ]
end  
  
  
  
to view-farm-size
  ask patches 
      [            
       ; Update the landuse type of those patches/fields that change landuse
       if patch-farm-size < 10                                 [set pcolor 3]    ; fields in farms smaller than 10ha.  
       if (patch-farm-size >= 10) and (patch-farm-size < 20)   [set pcolor 6]    ; fields in farms between 10-20ha. 
       if (patch-farm-size >= 20) and (patch-farm-size < 50)   [set pcolor 7]    ; fields in farms between 20-50ha. 
       if patch-farm-size >= 50                                [set pcolor 9]    ; fields in farms larger than 100ha. 
              
       if field-landuse = 0      [set pcolor white]    ; No data 
       if field-landuse = 6      [set pcolor white]    ; Urban areas  
       if field-landuse = 5      [set pcolor white]    ; Water
       if field-landuse = 4      [set pcolor white]    ; Nature areas   
      ]
end




to view-production-size
  ; Update the map based on the production scale of farms small vs. other farms
  ask agents 
      [
       ifelse agent-production-scale <= 50 
           [ask agent-farm-list [set pcolor blue + 2]]
           [ask agent-farm-list [set pcolor blue + 4]]
      ]
           
  ask patches 
      [ 
       if field-landuse = 0      [set pcolor white]    ; No data 
       if field-landuse = 6      [set pcolor white]    ; Urban areas  
       if field-landuse = 5      [set pcolor white]    ; Water
       if field-landuse = 4      [set pcolor white]    ; Nature areas               
      ]
end 
  
to view-soil-suitability-crops
  ask patches 
      [ 
       if field-suitability = 0    [set pcolor white] ; No data 
       if field-suitability > 0.3  [set pcolor 38]    ; Low  
       if field-suitability > 0.5  [set pcolor 36]    ; Medium
       if field-suitability > 0.7  [set pcolor 34]    ; High             
      ]
end
  
  

  


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; DEFINITION OF THE DIFFERENT PROBABILITIES ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to option-agent-initial 
  ask agents 
      [  
       ; Based on the previous land transactions, the initial conditions are defined in this step for:
  
       ; Farm cessation
       set agent-random-stop random-float 1
       
       ; Farm expansion
       ifelse agent-farm-expansion-sum > 0.1
           [set agent-random-expand (random-float (p-expand-type + 0.1))]
           [ifelse agent-farm-expansion-sum < -0.1 
                [set agent-random-expand ((0.9 - p-shrink-type) + random-float (p-shrink-type + 0.1))]
                [set agent-random-expand ((p-expand-type - 0.1) + random-float ((1 - p-shrink-type) - p-expand-type + 0.2))]
           ] 
  
       ; Protection of landscape elements
       set agent-random-protect random-float 1
      ]
end



to option-agent-type
  ; Probabilities based on the detailed sample survey (2001-2005). Probabilities to expand (0.06) and shrink (0.07) 
  ; are rescaled for 1 time step. 
    
  ask agents 
      [
       if agent-type = 1                    ; Hobby
           [                                
            set p-expand-type     0.01      ; Combined with p-shrink
            set p-shrink-type     0.05      ; Combined with p-expand, real value = 0.12
            set p-stop-type       0.34      ; Data based on farmers between 50-60 years old of the detailed survey 
            set p-protect-type    0.20      ; Define the probability to cut/keep/plant landscape elements
           ]
       if agent-type = 2                    ; Conventional 
           [                                
            set p-expand-type     0.28      ; Combined with p-shrink
            set p-shrink-type     0.04      ; Combined with p-expand, real value = 0.11
            set p-stop-type       0.36      ; Data based on farmers between 50-60 years old of the detailed survey 
            set p-protect-type    0.32      ; Define the probability to cut/keep/plant landscape elements
           ]
       if agent-type = 3                    ; Diversifier
           [                                
            set p-expand-type     0.35      ; Combined with p-shrink
            set p-shrink-type     0.10      ; Combined with p-expand, real value = 0.08
            set p-stop-type       0.32      ; Data based on farmers between 50-60 years old of the detailed survey 
            set p-protect-type    0.47      ; Define the probability to cut/keep/plant landscape elements
           ]
       if agent-type = 4                    ; Expansionist conventional
           [                                
            set p-expand-type     0.60      ; Combined with p-shrink
            set p-shrink-type     0.005     ; Combined with p-expand, real value = 0.02
            set p-stop-type       0.06      ; Data based on farmers between 50-60 years old of the detailed survey
            set p-protect-type    0.20      ; Define the probability to cut/keep/plant landscape elements
           ]
       if agent-type = 5                    ; Expansionist diversifier
           [                               
            set p-expand-type     0.64      ; Combined with p-shrink
            set p-shrink-type     0.005     ; Combined with p-expand, real value = 0.01
            set p-stop-type       0.05      ; Data based on farmers between 50-60 years old of the detailed survey
            set p-protect-type    0.47      ; Define the probability to cut/keep/plant landscape elements
           ]            
     ]
end             



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; QUANTIFICATION OF THE INFLUENCE OF PREVIOUS DECISIONS ON FUTURE OPTIONS ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
to feedback-internal-actions
   ; Increase of the agents' buying capacity per scenario (assumed values)
   if Scenario = "Basic"     [set index-growth 0]       
   if Scenario = "Trend"     [set index-growth 0.1]
   if Scenario = "B2"        [set index-growth 0.1]
   if Scenario = "A1"        [set index-growth 0.3]
   
   ask agents 
       [ 
        ; Propabibility that an agent will increase his farm-size based on her/his current farm size 
        ; and previous transactions (empirical data). Mean farm size is recalculate every time step 
        ; to include the general changes of farm size of the whole population through time
        
        let mean-farm-size mean [agent-farm-size] of agents
        if agent-farm-size < 10 ; unit ha.  
            [
             if (agent-farm-expansion-sum <= (2 * mean-farm-size * index-growth) and 
                (agent-farm-expansion-sum > mean-farm-size)) 
                [set p-expand-feedback (0.86 + index-growth)]
             
             if (agent-farm-expansion-sum <= mean-farm-size) and 
                (agent-farm-expansion-sum > 2)    
                [set p-expand-feedback (0.61 + index-growth)]
            ]
        if (agent-farm-size >= 10) 
            [
             if (agent-farm-expansion-sum <= 2 * mean-farm-size) and 
                (agent-farm-expansion-sum > mean-farm-size)   
                [set p-expand-feedback (0.73 + index-growth)]
             
             if (agent-farm-expansion-sum <= mean-farm-size) and 
                (agent-farm-expansion-sum > 2)    
                [set p-expand-feedback (0.45 + index-growth)]
            ]                 
        if agent-farm-expansion-sum > (2 * mean-farm-size) [set p-expand-feedback (0.20 + index-growth)] ; this value is the same for all agents                                                                                                          
        if agent-farm-expansion-sum > (4 * mean-farm-size) [set p-expand-feedback (0.05 + index-growth)] ; agents cannot grow anymore
        if agent-farm-expansion-sum <= 2                   [set p-expand-feedback 1]                     ; previous transactions do not influence agents' options

        ; Propabibility that an agent will stop farming based on her/his previous transactions (empirical data)
        ; The value 0.14 is half of the difference between farmers older than 50 who bought and who didn't buy any land between 2001-2005.
        if (agent-farm-expansion-sum < 0.1)  [set p-stop-feedback  0.14]
        if (agent-farm-expansion-sum >= 0.1) [set p-stop-feedback -0.14]
       ]

end




to feedback-internal-decisions ; influence of the previous in the subsequent random number 
  ask agents 
      [
       ; Based on the calibration of the amplitude of the curve, 0.06 was the selected value (calculated)
       set agent-random-expand random-normal agent-random-expand 0.06    
       set agent-random-protect random-normal agent-random-protect 0.06
                                       
       ; Probabilities need to be between 0 and 1.  
       if agent-random-expand < 0  [set agent-random-expand 0]
       if agent-random-expand > 1  [set agent-random-expand 1]
       if agent-random-protect < 0 [set agent-random-protect 0]
       if agent-random-protect > 1 [set agent-random-protect 1]
      ]
end
              



to feedback-exogenous-scenario ; incluence of the different scenarios in the probabilities
 ask agents 
     [
      if Scenario = "Basic" 
          [
           set p-exogenous-stop   1                                ; For the whole population, no influence  
           set p-business-stop    0                                ; For the whole population, no influence
           set p-exogenous-expand 0                                ; For the whole population, no influence
           set p-scenario-ehs     0                                ; For the whole population, no influence
          ] 

      if Scenario = "Trend"
          [
           set p-exogenous-stop 1.5                                ; For the whole population (assumed)
           set p-business-stop 0                                   ; For the whole population, no influence
           ifelse agent-type < 4                                   ; Difference between the buying capacity of non-expansionist and expansionist agents
               [set p-exogenous-expand 0.2]                        ; non-expansionits (assumed)
               [set p-exogenous-expand 0.3]                        ; expansionist (assumed)
          ] 

 
      if Scenario = "B2" 
          [
           set p-exogenous-stop 1.6                                 ; For the whole population (assumed)
           set p-business-stop 0                                    ; For the whole population, no influence 
           if agent-business-type = 1 [set p-business-stop -0.08]   ; Arable farms (calculated, secondary data)
           if agent-business-type = 4 [set p-business-stop  0.15]   ; Dairy farms (calculated, secondary data)
           if agent-business-type = 5 [set p-business-stop -0.06]   ; Other grassland farms (calculated, secondary data)
           if agent-business-type = 6 [set p-business-stop  0.15]   ; Intensive livestock farms (calculated)
           if agent-business-type = 7 [set p-business-stop  0.10]   ; Mixed farms (calculated, secondary data)
           ifelse agent-type < 4                                    ; Difference between the buying capacity of non-expansionist and expansionist agents
               [set p-exogenous-expand 0.2]                         ; non-expansionits (assumed)
               [set p-exogenous-expand 0.3]                         ; expansionist (assumed) 
          ]
                         
      if Scenario = "A1" 
          [
           set p-exogenous-stop 2                                   ; For the whole population (assumed)
           set p-business-stop 0                                    ; For the whole population, no influence
           if agent-business-type = 1 [set p-business-stop  0.06]   ; Arable farms (calculated, secondary data)
           if agent-business-type = 4 [set p-business-stop  0.09]   ; Dairy farms (calculated, secondary data)
           if agent-business-type = 5 [set p-business-stop -0.11]   ; Other grassland farms (calculated, secondary data)
           if agent-business-type = 6 [set p-business-stop  0.09]   ; Intensive livestock farms (calculated)
           if agent-business-type = 7 [set p-business-stop -0.04]   ; Mixed farms (calculated, secondary data)
           ifelse agent-type < 4                                    ; Difference between the buying capacity of non-expansionist and expansionist agents
               [set p-exogenous-expand 0.2]                         ; non-expansionits (assumed)
               [set p-exogenous-expand 0.4]                         ; expansionist (assumed)
          ]
    ]
end 



to feedback-endogenous-landscape 
  ; feedback only included in the A1 scenario. Immigrants from the urban areas can buy hobby farms (likelihood 0.5)
  ; when these are located in areas surrounded more than 10% with nature (assumed).
  let random-sell random-float 1
  if random-sell > 0.5 and Scenario = "A1" and agent-farm-size < 10
      [
       ; Count all patches in the study area within a radius of 1Km
       let patches-around count patches with [field-landuse > 0 and distance myself < 10]
       ; Count patches with nature in the study area within a radius of 1Km
       let nature-around count patches with [field-landuse = 4 and distance myself < 10]
       ; Calculate the propotion of surrouding nature area 
       set agent-surrounding-nature (nature-around / patches-around)
       ; Those with more than 10% of nature are sold to urban immigrants and probabilities are re-calculated
       if agent-surrounding-nature > 0.1
           [
            set agent-random-expand (random-float 1)
            set agent-type 1
            set agent-age 37
            set agent-new 1
            set agent-cessation ""
            set agent-expansion ""
            set agent-protection ""                
           ]
      ]
end 





;;;;;;;;;;;;;;;;;;;
; AGENTS' OPTIONS ;
;;;;;;;;;;;;;;;;;;;

to farm-cessation-option
  ask agents 
     [
      ; Those agents who haven't decided yet can decide whether to stop farming
      if (agent-cessation = "")
         [
          ; The likelihood to stop farming depends on agent type, the influence of the exogenous processes on the agent population 
          ; and the agribusiness type, and the previous land transactions 
          set p-stop (p-stop-type * (p-exogenous-stop) * (1 + p-business-stop) * (1 + p-stop-feedback))
          ; In the B2 scenario, the probability of stop farming depends on two more variables 
          if Scenario = "B2"
              [
               ; agents who live in the national landscape are less likely to stop farming (assumed)
               ifelse agent-national-landscape = 1
                   [set p-stop (p-stop * 0.9)]
                   [set p-stop (p-stop * 1.1)]
               ; diversifiers are less likely to stop in this scenario (assumed)
               ifelse (agent-type = 3 or agent-type = 5)
                   [set p-stop (p-stop * 0.9)]
                   [set p-stop (p-stop * 1.1)] 
              ]
          ; Probabilities need to be between 0 and 1
          if p-stop < 0 [set p-stop 0]
          if p-stop > 1 [set p-stop 1]
         ]
     ]    
end





to farm-expansion-option
  ask agents 
      [
       ; The likelihood to buy/sell land depends on the agent type, the previous land transactions and 
       ; the exogenous processes of each scenario
       set p-expand (p-expand-type * p-expand-feedback * (1 + p-exogenous-expand)) 
       ; In the B2 scanerio, because the active development of the EHS, agents with fields in the EHS are 100% 
       ; more likely to sell that parcel (assumed)
       ifelse Scenario = "B2"
           [
            ifelse any? agent-farm-list with [field-ehs = 1]
                [set p-scenario-ehs 1] 
                [set p-scenario-ehs 0]
           ]
           [set p-scenario-ehs 0]            
       set p-shrink (p-shrink-type * (1 + p-scenario-ehs))  
       ; Probabilities need to be between 0 and 1
       if p-expand < 0 [set p-expand 0]
       if p-expand > 1 [set p-expand 1]
       if p-shrink < 0 [set p-shrink 0]
       if p-shrink > 1 [set p-shrink 1]
      ]
end



to protection-trees-option  
  ; The likelihood to protect/cut landscape elements only depends on the agent-type
  ask agents
      [
       set p-protect (p-protect-type) 
      ]
end







;;;;;;;;;;;;;;;;;;;;;
; AGENTS' DECISIONS ;
;;;;;;;;;;;;;;;;;;;;;

to farm-cessation-decision
  ask agents  
      [
       ; Agents older than 50 decide whether to stop or inherit their farms
       if agent-age > 50 
         [
           ; This decision is the combination of a random number and the likelihood to stop farming
           ifelse (agent-random-stop < p-stop) 
               [
                set agent-cessation "stop"
                ; TRANSITIONAL RUPTURE, agents who were expansionst become non-expansinist 
                if agent-type = 4 [set agent-type 2]
                if agent-type = 5 [set agent-type 3]
                ; Their probabilities are recalculated, but they are 0.5 more likely to sell their farms (assumed)
                option-agent-type
                set agent-random-expand (0.5 + random-float 0.5)
               ]
               ; Those who don't stop will inherit their farm (no changes in agent type)
               [set agent-cessation "inherit"] 
        ]
     ]
end




to farm-expansion-decision
  ask agents 
      [  
       ; Agents who will stop are quite unlikely to grow (only 7%), therefore it's assumed they don't grow (empirical data)
       ; The decision of buying land depends on three main factors:
       ifelse (p-expand > agent-random-expand) and    ; The agent wants to expand AND
       (agent-cessation != "stop")             and    ; the agent is not planning to stop farming AND
       (agent-farm-expansion-sum > -1)                ; the agent hasn't sold any land > 1ha. in the last five years.
              [set agent-expansion "buy"]
              [set agent-expansion "stable"]
       
                                                                  
       ; The decision of selling land depends on three factors 
       if ((1 - p-shrink) < agent-random-expand) and  ; The agent wants to sell AND
       (length agent-field-list > 1)             and  ; the agent has more than 1 field AND
       (agent-farm-expansion-sum < 1)                 ; the agent hasn't bought any land > 1ha. in the last five years.
             [set agent-expansion "sell"]

      ]  
end 



to protection-trees-decision
  ; The decision of cutting and planting landscape elements depends on the scenario.
  if Scenario = "A1" 
      [
       ask agents 
           [
            ; Agents can only take decisions 6 years after their last decisions, which is the normal 
            ; period for this kind protection programmes
            if agent-decision-trees >= 6
                [
                 ; The cutting of landscapa elements depends on whether there is an element in agents' field and
                 ; on the suitability of the field
                 let field-cut all? agent-farm-list [field-le = 1 and field-suitability > 0.5]
                 ; Those who have landscdape elements in their fields, who want to cut them and who are not hobby 
                 ; agents would cut them. The other agents would keep them.
                 ifelse (field-cut != []) and (p-protect < agent-random-protect) and (agent-type != 1)
                      [set agent-protection "cut"] 
                      [set agent-protection "keep"]
                 ; After they take a decision, the new decision time is 0
                 set agent-decision-trees 0            
                ]
           ]
      ]
      
  if Scenario = "B2"
      [
       ask agents 
           [
            ; Agents can only take decisions 6 years after their last decisions, which is the normal 
            ; period for this kind protection programmes
            if agent-decision-trees >= 6
                [
                 ; The decision to cut landscape elements depend on three factors
                 ifelse (agent-trees = 1) and                          ; the agent has these elements in the farm
                        (p-protect * 1.5 < agent-random-protect) and   ; the agent wants to cut them (assumed)
                        (agent-type != 1)                              ; the agent is not a hobby agent
                     [set agent-protection "cut"] 
                     [set agent-protection "keep"]            
            
                 ; The decision to plant new landscdape elements depend on two factors 
                 if (p-protect > agent-random-protect) and   ; The agent wants to plant them
                    (agent-type != 1)                        ; The agent is not a hobby agent
                     [set agent-protection "plant"]
                 ; After they take a decision, the new decision time is 0
                 set agent-decision-trees 0 
                ]
           ]
     ]
end 





;;;;;;;;;;;;;;;;;;;
; AGENTS' ACTIONS ;
;;;;;;;;;;;;;;;;;;;

to farm-cessation-action 
   ; Depending on the scenario, the proportion of agents stopping farming each year varies. This has to be calculated per year (calculated, secondary data) 
   if Scenario = "Basic"  [set index-stop-year 0.1]       
   if Scenario = "Trend"  [set index-stop-year (0.025 * (count agents) / (count agents with [agent-cessation = "stop"]))]
   if Scenario = "B2"     [set index-stop-year (0.029 * (count agents) / (count agents with [agent-cessation = "stop"]))]
   if Scenario = "A1"     [set index-stop-year (0.040 * (count agents) / (count agents with [agent-cessation = "stop"]))] 
   
   ask agents
       [
        ; only agents older than 65 years are able to inherit their farm
        if agent-cessation = "inherit" and agent-age >= 65 
             [
              let percentage-agents random-float 1
              ; Agents younger than 84 have 0.1 likelihood to inherit their farm (empirical data) 
              ; and agents 84 years old inherit the farm
              if (percentage-agents < 0.1) or (agent-age >= 84) 
                    [
                     ; The new agent is 37 years old (empirical data) and follows the same strategy as the predecessor
                     set agent-age 37
                     set agent-cessation ""
                    ]       
             ]
      
      
        if agent-cessation = "stop"
            [
             ; The process of stop farming differ between scenarios
             
             ; Based on a random number and the expected number of agent to stop per year or when they are older than 84, agents stop farming
             let percentage-agents random-float 1   
             if (percentage-agents < index-stop-year) or (agent-age >= 84) 
                 [
                  ifelse Scenario = "A1"
                      [
                       ; In the A1 scenario, to sell fields that are part of the EHS in order to develop nature depends on a  
                       ; random number and the suitability of the field for agriculture, the lower the suitability the higher chance to be sold
                       let random-ehs (random-float 1 + field-suitability) / 2
                       if random-ehs < 0.5
                           [
                            ; EHS development 
                            let fields-ehs patches with [
                                                         (field-owner-id = [agent-id] of myself) and ; patches that the agent owned
                                                         (field-ehs = 1)                             ; patches in the EHS
                                                        ] 
                            ask fields-ehs 
                                [
                                 set field-owner-id 9999      ; patches sold to the nature development organisation
                                 set field-landuse  4         ; new land-use nature
                                ]
                            set agent-farm-list patches with [field-owner-id = [agent-id] of myself]
                            set agent-field-list remove-duplicates definition-farms                    
                            
                            ; Those agent without any other field will quite
                            if (agent-farm-list = []) or (agent-field-list = []) [die]   
                           ]
                       
                       ; In the A1 scenario, non-hobby agents are (0.5) likely to sell their fields not suitable for 
                       ; agriculture and outside the EHS to be converted into nature
                       let random-abandon random-float 1
                       if agent-type > 1 and random-abandon > 0.5
                           [
                            ; Nature development 
                            let fields-abandon patches with [
                                                             (field-owner-id = [agent-id] of myself) and
                                                             (field-suitability < 0.5)
                                                            ]
                            ask fields-abandon 
                                [
                                 set field-owner-id 9999   ; patches sold to the nature development organisation
                                 set field-landuse  4      ; new land-use nature
                                ]
                            set agent-farm-list patches with [field-owner-id = [agent-id] of myself]
                            set agent-field-list remove-duplicates definition-farms                    

                            ; Those agent without any other field will quite
                            if (agent-farm-list = []) or (agent-field-list = []) [die]
                           ]
                       ]

                  [                  
                   ; In the other sceanrios fields located in the EHS are abandoned 
                   let fields-ehs patches with [(field-owner-id = [agent-id] of myself) and (field-ehs = 1)] 
                        ; EHS development 
                        ask fields-ehs 
                            [
                             set field-owner-id 9999
                             set field-landuse  4
                            ]
                        set agent-farm-list patches with [field-owner-id = [agent-id] of myself]
                        set agent-field-list remove-duplicates definition-farms                    
                        
                        ; Those agent without any other field will quite
                        if (agent-farm-list = []) or (agent-field-list = []) [die]                                     
                  ]
                                                                       
                  ; From the land left, big farms (> 5 fields) are sold to different buyers (assumed)
                  while [length agent-field-list > 5]
                      [
                       ; Selection of the buyer
                       ; The buyer should be close to the seller
                       let agent-buyers min-n-of 10 agents with [agent-expansion = "buy"] [distance myself] 
                       ask agent-buyers 
                           [
                            ; the variables to selected the buyer are reset to change previous values
                            set weight-size 0
                            set weight-distance 0
                            set weight-type 0
                            ; the variables to select the buyer are re-calculated
                            let weight-random random-float 0.1
                            if agent-farm-size > [agent-farm-size] of myself [set weight-size 0.1]
                            if distance myself < 20 [set weight-distance 0.1]   
                            if agent-type > 3 [set weight-type 0.1]
                            set weight-buy (weight-size + weight-distance + weight-type + weight-random)
                           ] 
                       ; Selection of the buyer
                       let agent-buyer max-one-of agent-buyers [weight-buy]
                       ; Five fields to be sold are selected  
                       let patches-sell n-of 5 agent-farm-list 
                       
                       ; Land transaction
                       ask patches-sell [set field-owner-id ([agent-id] of agent-buyer)]
                        
                       ; Update the land owned and land transactions by the closest buyer
                       ask agent-buyer 
                           [
                            set agent-farm-list patches with [field-owner-id = [agent-id] of myself]
                            ask agent-farm-list [set field-distance-owner distance myself]
                            set agent-field-list remove-duplicates definition-farms
                            set agent-expansion "bought"
                           ]
                        ; Update the farm of the seller 
                        set agent-farm-list patches with [field-owner-id = [agent-id] of myself]
                        set agent-field-list remove-duplicates definition-farms
                       ]                         
                   
                   ; Before agents stop farming they can sell their farm to urban immigrants (only hobby and in the A1 scenario)
                   feedback-endogenous-landscape
                   
                   ; Agents who are not new immigrants would continue selling their land
                   if agent-new = 0 
                   [       
                   ; The rest of big farms or small farms are sold to one buyer 
                   ; The buyer should be close to the seller
                   let agent-buyers min-n-of 10 agents with [agent-expansion = "buy"] [distance myself]
                        
                        ask agent-buyers 
                            [
                             ; the variables to selected the buyer are reset
                             set weight-size 0
                             set weight-distance 0
                             set weight-type 0
                             ; the variables to select the buyer are calculated
                             let weight-random random-float 0.1
                             if agent-farm-size > [agent-farm-size] of myself [set weight-size 0.1]
                             if distance myself < 20 [set weight-distance 0.1]   
                             if agent-type > 3 [set weight-type 0.1]
                             set weight-buy (weight-size + weight-distance + weight-type + weight-random)
                            ] 
                   ; Selection of the buyer
                   let agent-buyer max-one-of agent-buyers [weight-buy] 
                                                                                                                                                     
                   ;; Land transaction  
                   ask agent-farm-list [set field-owner-id ([agent-id] of agent-buyer)]
                 
                   ; Update the land owned and land transactions by the closest buyer
                   ask agent-buyer 
                       [
                        set agent-farm-list patches with [field-owner-id = [agent-id] of myself]
                        ask agent-farm-list [set field-distance-owner distance myself]
                        set agent-field-list remove-duplicates definition-farms
                        set agent-expansion "bought"
                       ]
                   ; The seller stops farming
                   die
                  ]
                  ]
             ]
       ]
end





to farm-expansion-action
  ; Transaction when an agent leases/sell only a field. This process also depends on the scenario.
  ask agents 
    [
     if agent-expansion = "sell" 
        [
         ; In the B2 scenario, fields in the EHS are sold. If agents don't have one in the EHS, they sell the farthest one 
         ifelse Scenario = "B2"
             [
              ifelse any? agent-farm-list with [field-ehs = 1]
                  [set agent-field-sell one-of agent-farm-list with [field-ehs = 1]]          
                  [set agent-field-sell (max-one-of agent-farm-list [field-distance-owner])]
             ]
             [set agent-field-sell (max-one-of agent-farm-list [field-distance-owner])] 
              ; In the Basic, Trend and B2 scenarios, fields that are in the EHS are developed into nature.
              ; In the A1 scenrio, only those located in the EHS with low suitability are converted to nature.
              ifelse (Scenario != "A1" and
                     [field-ehs] of agent-field-sell = 1) or 
                     (Scenario = "A1" and
                     [field-ehs] of agent-field-sell = 1 and 
                     [field-suitability] of agent-field-sell < 0.5)
                  [
                   ; Nature development  
                   ask agent-field-sell 
                       [
                        set field-owner-id 9999
                        set field-landuse  4
                       ]
                   set agent-farm-list patches with [field-owner-id = [agent-id] of myself]
                   set agent-field-sell []
                   set agent-field-list remove-duplicates definition-farms                    
                   if (agent-farm-list = []) or (agent-field-list = []) [die]
                  ] 
                  [
                   ; select the number of the field to which such a patch belongs
                   let parcel-field-number-sell ([parcel-field-number] of agent-field-sell)
                                                                  
                   ; Define the patches of that field  
                   let patches-sell patches with [(parcel-field-number > 0) and (parcel-field-number = parcel-field-number-sell)]         
          
                   ; Individual fields are sold to the closest buyer 
                   let agent-closest-buyer min-one-of agents with [agent-expansion = "buy"] [distance myself]  
       
                   ; The closest buyer gets the field 
                   ask patches-sell [set field-owner-id ([agent-id] of agent-closest-buyer)]
                                                                
                   ; Update the land owned and land transactions by the closest buyer
                   ask agent-closest-buyer 
                        [
                         set agent-farm-list patches with [field-owner-id = [agent-id] of myself]
                         ask agent-farm-list [set field-distance-owner distance myself]
                         set agent-field-list remove-duplicates definition-farms
                         set agent-expansion "bought"
                        ]
                  
                   ; Update land of the seller 
                   set agent-farm-list patches with [field-owner-id = [agent-id] of myself]
                   set agent-field-list remove-duplicates definition-farms
                   set agent-field-sell []
                   set agent-expansion "sold"

                                                                                                                               
                   ; Agents without more land left stop farming 
                   if (agent-farm-list = []) or (agent-field-list = []) [die]
                  ]
             ]
        ;]
    ]
end 



to protection-trees-action
  ; The process to cut or plant landscape elements depend on the scenario
  
  if Scenario = "A1" 
      [
       ask agents 
           [ 
            if agent-protection = "cut" 
                [
                 ; Patches where landscape can be cut are chosen based on three factors 
                 let patches-cut patches with [
                                               (field-owner-id = [agent-id] of myself) and ; the agent owns the field 
                                               (field-le = 1) and                          ; the field has landscape elements
                                               (field-suitability > 0.5)                   ; the field is suitable for agriculture
                                              ]
                  
                 ; For those you want and who have fields with landspcape elements cut them                
                 if patches-cut != no-patches 
                 ; Change the landuse type of that field
                     [
                      ask patches-cut 
                          [
                           set field-le 0
                           set field-le-current 0
                          ]

                      set agent-protection "done"
                      set agent-cut 1                        
                     ]                     
                ]
           ]
     ]
  if Scenario = "B2"
      [
       ask agents
           [
            if agent-protection = "cut" 
                [
                 ; Patches where landscape can be cut are chosen based on three factors
                 let patches-cut patches with [
                                               (field-owner-id = [agent-id] of myself) and ; the agent owns the field
                                               (field-le = 1) and                          ; the field has landscape elements 
                                               (field-suitability > 0.7)                   ; the field is highly suitable for agriculture 
                                              ]
                 ; For those you want and who have fields with landspcape elements cut them                              
                 if patches-cut != no-patches                 
                 ; Change the landuse type of that field
                     [
                      ask patches-cut 
                          [
                           set field-le 0
                           set field-le-current 0
                          ]

                      set agent-protection "done"
                      set agent-cut 1                        
                     ]
                ]            
            
            
            if agent-protection = "plant" 
                [
                 ; Patches where landscape elements can be planted are chosen based on three factors 
                 let fields-plant agent-farm-list with 
                                                       [
                                                        (field-owner-id = [agent-id] of myself) and     ; the agents owns the field
                                                        (field-suitability < 0.6) and                   ; the field is not highly suitable for agriculture
                                                        (field-le-current / field-le-potential < 0.25)  ; the field doesn't have many landscape elements
                                                       ]
                 ; For those you want and who have fields with landspcape elements to be planted                               
                 if fields-plant != no-patches                 
                     [
                      ; Selection of the field 
                      let field-plant one-of fields-plant
                      let field-plant-number ([parcel-field-number] of field-plant)
                      let patches-plant patches with [parcel-field-number = field-plant-number]                  
                      
                      ; Change the amount of landscape elements in the field
                      ask patches-plant 
                           [
                            set field-le 1
                            set field-le-current (field-le-current + field-le-potential / 4)
                           ]
                      set agent-protection "done"
                      set agent-plant 1   
                     ]
               ]
          ]
     ]
end 








;;;;;;;;;;;;;;;;;;;;
;  REPORT RESULTS  ;
;;;;;;;;;;;;;;;;;;;; 


to-report export-next-index [prefix suffix]
  ; To create different output file names 
  let index 0
  let filename (word prefix index suffix)
  while [file-exists? filename]
            [ 
             set index index + 1 
             set filename (word prefix index suffix)
            ]
  report index
end


to export-data
  ; To export output    
end

@#$#@#$#@
GRAPHICS-WINDOW
93
10
402
408
-1
-1
1.0
1
10
1
1
1
0
0
0
1
0
298
0
366
1
1
1
ticks

BUTTON
15
12
70
45
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

MONITOR
18
363
68
408
Agents
count agents
0
1
11

BUTTON
15
46
70
79
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
15
80
70
113
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
18
420
210
553
Percentage of agents
NIL
NIL
0.0
15.0
0.0
30.0
true
false
PENS
"Agents" 1.0 0 -16777216 true
"Hobby" 1.0 0 -2674135 true
"Conventional" 1.0 0 -11221820 true
"Diversifier" 1.0 0 -10899396 true
"Diversifier expansionist" 1.0 0 -13345367 true
"Conventional expansionist" 1.0 0 -6459832 true

PLOT
212
419
548
552
Mean farm size
time
dsu
0.0
15.0
0.0
10.0
true
true
PENS
"Total" 1.0 0 -16777216 true
"Hobby" 1.0 0 -2674135 true
"Conventional" 1.0 0 -11221820 true
"Diversifier" 1.0 0 -10899396 true
"Diversifier expansionist" 1.0 0 -13345367 true
"Conventional expansionist" 1.0 0 -6459832 true

CHOOSER
454
53
546
98
Scenario
Scenario
"Basic" "Trend" "A1" "B2"
1

TEXTBOX
475
164
528
186
Views
20
103.0
1

BUTTON
446
233
550
266
Farm size
view-farm-size
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
446
267
550
300
Production size
view-production-size
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
446
301
550
334
Field elements
view-field-le
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
446
199
550
232
Agent types
view-agent-type
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
18
555
210
683
Percentage of area
NIL
NIL
0.0
15.0
0.0
10.0
true
false
PENS
"Hobby" 1.0 0 -2674135 false
"Conventional" 1.0 0 -11221820 true
"Diversifier" 1.0 0 -10899396 true
"Conventional expansionist" 1.0 0 -6459832 true
"Diversifier expansionist" 1.0 0 -13345367 true

BUTTON
446
335
550
368
Suitability crops
view-soil-suitability-crops
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
213
555
382
684
Trees
NIL
NIL
0.0
15.0
0.0
10.0
true
false
PENS
"Total" 1.0 0 -16777216 true
"Hobby" 1.0 0 -2674135 true
"Conventional" 1.0 0 -11221820 true
"Diversifier" 1.0 0 -10899396 true
"Conventional expansionist" 1.0 0 -6459832 true
"Diversifier expansionist" 1.0 0 -13345367 true

PLOT
383
555
548
684
Nature
NIL
NIL
0.0
15.0
0.0
10.0
true
false
PENS
"per year" 1.0 0 -16777216 true

@#$#@#$#@
WHAT IS IT?
-----------
This section could give a general understanding of what the model is trying to show or explain.


HOW IT WORKS
------------
This section could explain what rules the agents use to create the overall behavior of the model.


HOW TO USE IT
-------------
This section could explain how to use the model, including a description of each of the items in the interface tab.


THINGS TO NOTICE
----------------
This section could give some ideas of things for the user to notice while running the model.


THINGS TO TRY
-------------
This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.


EXTENDING THE MODEL
-------------------
This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.


NETLOGO FEATURES
----------------
This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.


RELATED MODELS
--------------
This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.


CREDITS AND REFERENCES
----------------------
This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

house efficiency
false
0
Rectangle -7500403 true true 180 90 195 195
Rectangle -7500403 true true 90 165 210 255
Rectangle -16777216 true false 165 195 195 255
Rectangle -16777216 true false 105 202 135 240
Polygon -7500403 true true 225 165 75 165 150 90
Line -16777216 false 75 165 225 165

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Shape" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="std">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Randomness" repetitions="5" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
  </experiment>
  <experiment name="scenarios" repetitions="20" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="Scenario">
      <value value="&quot;Current trends&quot;"/>
      <value value="&quot;Regional communities&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
